errors

package module
v0.0.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2025 License: Apache-2.0 Imports: 3 Imported by: 1

README

errors

Documentation

Overview

Copyright 2024 kenita8

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

var (
	As = errors.As
	Is = errors.Is
)

Functions

This section is empty.

Types

type SentinelError added in v0.0.4

type SentinelError struct {
	// contains filtered or unexported fields
}

func New

func New(msg string) *SentinelError

func (*SentinelError) Error added in v0.0.4

func (s *SentinelError) Error() string

func (*SentinelError) Is added in v0.0.4

func (s *SentinelError) Is(target error) bool

func (*SentinelError) WithDetails added in v0.0.4

func (s *SentinelError) WithDetails(kv ...any) *WrappedError

func (*SentinelError) Wrap added in v0.0.4

func (s *SentinelError) Wrap(err error) *WrappedError

type WrappedError

type WrappedError struct {
	// contains filtered or unexported fields
}

func (*WrappedError) As added in v0.0.4

func (e *WrappedError) As(target any) bool

func (*WrappedError) Error

func (s *WrappedError) Error() string

func (*WrappedError) Is

func (e *WrappedError) Is(target error) bool

func (*WrappedError) Unwrap

func (e *WrappedError) Unwrap() error

func (*WrappedError) WithDetails added in v0.0.4

func (s *WrappedError) WithDetails(kv ...any) *WrappedError

func (*WrappedError) Wrap

func (s *WrappedError) Wrap(err error) *WrappedError

Directories

Path Synopsis

Jump to